@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -746,11 +746,14 @@ public class ReportClient extends AbstractJMXTools {
             Long start = (Long) report.get("startTime");
             Long end = (Long) report.get("stopTime");
 
-            long elapsedTime = end - start;
+            long elapsedTime = end.longValue() - start.longValue();
+            if (elapsedTime < 0) {
+                elapsedTime = -elapsedTime;
+            }
 
             Integer totalContexts = (Integer) report.get("tasks");
 
-            long timePerContext = elapsedTime / totalContexts;
+            long timePerContext = elapsedTime / totalContexts.longValue();
 
             System.out.println("UUID: " + report.get("uuid"));
             System.out.println("Type: " + report.get("type"));
